# -*- coding: utf-8 -*-
"""
Created on Sun Jan 24 19:10:18 2021

@author: yasse
"""

url = 'http://144.91.87.145:3000'
token = ''
tickers = ['all']
